==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/ronportal/vyroba/view_denni_vyroba_osoby.php <==
<?php
/**
 * stanislav.elbl, 06.09.2018
 */

namespace RonPortal\Vyroba;

use Ron\DateUtils;
use Ron\MessageManager;
use Ron\StringUtils;
use RonPortal\RonPortalSettings;

/** @var DenniVyrobaOsobyForm $this */

$odpracovanoStr = StringUtils::format('minuty', round($this ->odpracovano * 60));
$soucetStr = StringUtils::format('minuty', round($this ->soucet * 60));
$zbyva = round(($this ->odpracovano - $this ->soucet) * 60);
$zbyvaStr = StringUtils::format('minuty', $zbyva);

$colZakazka = 6 - ($this ->editovatHodiny ? 1 : 0) - ($this ->editovatCasy ? 1 : 0);
$colCinnost = 5 - ($this ->editovatCasy ? 1 : 0);

?>

<div class="rozdeleniVyrobyOsoby" data-idpp="<?= $this ->pp ->idPP ?>" data-den="<?= DateUtils::dateToUrlString($this ->den) ?>">
    <input type="hidden" name="ulozrozdelenivyroby" value="1"/>

    <div class="row form-section">
        <div class="col col-<?= $colZakazka ?>"><?= \Ron\ronText('Vyroba_zakazka') ?></div>
        <div class="col col-<?= $colCinnost ?>"><?= \Ron\ronText('Vyroba_cinnost') ?></div>

        <?php if ($this ->editovatCasy) { ?>
            <div class="col col-1"><?= \Ron\ronText('Vyroba_casod') ?></div>
            <div class="col col-1"><?= \Ron\ronText('Vyroba_casdo') ?></div>
        <?php } ?>

        <?php if ($this ->editovatHodiny) { ?>
        <div class="col col-1"><?= \Ron\ronText('Vyroba_hodiny') ?></div>
        <?php } ?>
    </div>

    <?php
    foreach ($this ->zaznamy as $index => $zaznam) { ?>
        <div id="vyroba_row<?= $index ?>" class="radekDenniVyrobyOsoby" data-rowindex="<?= $index ?>">
            <input type="hidden" name="vyroba<?= $index ?>_serial" value="<?= $zaznam ->serialVyroba ?>" />
            <div class="row">
                <div class="col col-<?= $colZakazka ?>"><?php $this ->renderComboZakazka("vyroba{$index}_vyrobniZakazka", $zaznam ->zakazka); ?></div>
                <div class="col col-<?= $colCinnost ?>"><?php $this ->renderComboCinnost("vyroba{$index}_cinnost", $this ->jenPrirazeneCinnosti ? $zaznam ->cinnostVyrobniZakazky : $zaznam ->cinnost, $zaznam ->zakazka) ?></div>

                <?php if ($this ->editovatCasy) { ?>
                    <div class="col col-1">
                        <input name="vyroba<?= $index ?>_casOd" <?= $this ->readOnly ? 'readonly="readonly"' : '' ?>
                               class="form-input align-right inputTime vyroba_casOd <?= MessageManager::getClass("vyroba{$index}_casOd")?>"
                               value="<?= StringUtils::htmlTextConvert($zaznam ->casOdStr) ?>"/>
                    </div>
                    <div class="col col-1">
                        <input name="vyroba<?= $index ?>_casDo" <?= $this ->readOnly ? 'readonly="readonly"' : '' ?>
                               class="form-input align-right inputTime vyroba_casDo <?= MessageManager::getClass("vyroba{$index}_casDo")?>"
                               value="<?= StringUtils::htmlTextConvert($zaznam ->casDoStr) ?>"/>
                    </div>
                <?php } ?>

                <?php if ($this ->editovatHodiny) { ?>
                <div class="col col-1">
                    <input name="vyroba<?= $index ?>_hodiny" <?= $this ->readOnly ? 'readonly="readonly"' : '' ?>
                           class="form-input align-right inputTime vyroba_hodiny <?= MessageManager::getClass("vyroba{$index}_hodiny")?>"
                           value="<?= StringUtils::htmlTextConvert($zaznam ->hodinyStr) ?>"/>
                </div>
                <?php } ?>

                <div class="col col-1">
                    h
                    <?php if (!$this ->readOnly) { ?>
                    <i class="inline-glyph glyph-button far fa-comment-alt toggleClass " data-selector="#vyroba_row<?= $index ?>" data-add-class="zobrazitPoznamky" title="<?= \Ron\ronText('Zobrazit_poznamky') ?>">
                    </i>

                        <?php if ($zaznam ->serialVyroba) { ?>
                        <i class="inline-glyph glyph-button fa glyph-delete vyroba_delete" title="<?= \Ron\ronText('Smazat_cely_radek') ?>" data-ron-confirm-text="<?= \Ron\ronText('Opravdu_smazat_cely_radek') ?>" data-serial="<?= $zaznam ->serialVyroba ?>"></i>
                        <?php } ?>
                    <?php } ?>
                </div>
            </div>
            <!-- poznamky -->
            <div class="row popis <?= $zaznam ->popis ? '' : 'prazdnyPopis' ?>">
                <div class="col col-11">
                    <?php if ($this ->readOnly) { ?>
                        <div class="poznamka"><?= StringUtils::htmlTextConvert($zaznam ->popis) ?></div>
                    <?php } else { ?>
                        <input maxlength="80" name="vyroba<?= $index ?>_popis" class="form-input" value="<?= StringUtils::htmlTextConvert($zaznam ->popis) ?>"/>
                    <?php } ?>
                </div>
                <div class="col col-1 overflow-hidden"><?= \Ron\ronText('Vyroba_popis') ?></div>
            </div>
            <div class="row rozsirujiciPopis <?= $zaznam ->rozsirujiciPopis ? '' : 'prazdnyPopis' ?>">
                <div class="col col-11">
                    <?php if ($this ->readOnly) { ?>
                        <div class="poznamka"><?= StringUtils::htmlTextConvert($zaznam ->rozsirujiciPopis) ?></div>
                    <?php } else { ?>
                        <textarea name="vyroba<?= $index ?>_rozsirujiciPopis" class="form-input"><?= StringUtils::htmlTextConvert($zaznam ->rozsirujiciPopis) ?></textarea>
                    <?php } ?>
                </div>
                <div class="col col-1 overflow-hidden"><?= \Ron\ronText('Vyroba_rozsirujici_popis') ?></div>
            </div>
            <div class="form-gap popis <?= $zaznam ->popis || $zaznam ->rozsirujiciPopis ? '' : 'prazdnyPopis' ?>"></div>
        </div>
    <?php } ?>

    <!-- soucet -->
    <?php if (isset($this ->odpracovano)) { // zobrazi soucet/kolik zbyva ?>
        <div class="row">
            <div class="col col-6"><?= \Ron\ronText('Celkem_rozdelit') ?>: <strong><?= $odpracovanoStr ?></strong></div>
            <div class="col col-5 align-right">
                <?= \Ron\ronText('Zbyva_rozdelit') ?>:
                <strong><span class="input_margins<?= $zbyva < 0 ? ' minus' : '' ?>" data-ron-sum="<?= $odpracovanoStr ?>" id="Vyroba_Zbyva"><?= $zbyvaStr ?></span></strong>
            </div>
            <div class="col col-1">h</div>
        </div>
    <?php } else { ?>
        <div class="row">
            <div class="col col-11 align-right"><?= \Ron\ronText('Soucet') ?>: <strong><span id='Vyroba_Soucet'><?= $soucetStr ?></span></strong></div>
            <div class="col col-1">h</div>
        </div>
    <?php } ?>

    <input type="hidden" name="vyroba_COUNT" id="vyroba_COUNT" value="<?= count($this ->zaznamy) ?>" />
    <input type="hidden" name="vyroba_delete_row" id="vyroba_delete_row" value="" />

    <?php if (!$this->readOnly) { // umozni pridat novy radek pomoci tlacitka ?>
        <div class="row">
            <div class="col col-3">
                <input class="button" type="submit" name="novyradekvyroby" value="<?= \Ron\ronText('Novy_radek') ?>" />
            </div>

            <div class="col col-9 align-right">
                <input class="button" type="submit" id="vyroba_doplnitpodlepredchozi" name="doplnitpodlepredchoziho"
                       value="<?= \Ron\ronText('Doplnit_vyrobu_podle_predchoziho') ?>"
                       title="<?= \Ron\ronText('Doplnit_vyrobu_podle_predchoziho_dne_info') ?>" />
                <?php if (RonPortalSettings::getValue('vyroba_agenthost')) { ?>
                <input class="button confirmQuestion" type="button" id="vyroba_podlepuvodni" name="podlepuvodnivyroby"
                       value="<?= \Ron\ronText('Vyroba_podle_puvodni') ?>"
                       title="<?= \Ron\ronText('Vyroba_podle_puvodni_info') ?>"
                       data-ron-href="?menuid=editacedne&action=podlepuvodnivyroby&idpp=<?= $this ->pp ->idPP ?>&datum=<?= $this ->den ?>"
                       data-ron-confirm-text="<?= \Ron\ronText('Opravdu_podle_puvodni_vyroby') ?>"
                       data-ron-working-info="<?= \Ron\ronText('Probiha_zpracovani_dat') ?>"
                    />
                <?php } ?>
            </div>
        </div>
    <?php } ?>

    <!-- POZNAMKA ! -->
</div>

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2302_169.zip: ronportal/ronportal/vyroba/view_denni_vyroba_osoby.php <==
<?php
/**
 * stanislav.elbl, 06.09.2018
 */

namespace RonPortal\Vyroba;

use Ron\DateUtils;
use Ron\MessageManager;
use Ron\StringUtils;
use RonPortal\RonPortalSettings;
use RonPortal\RonPortalXMLEvents;

/** @var DenniVyrobaOsobyForm $this */

$odpracovanoStr = StringUtils::format('minuty', round($this ->odpracovano * 60));
$soucetStr = StringUtils::format('minuty', round($this ->soucet * 60));
$zbyva = round(($this ->odpracovano - $this ->soucet) * 60);
$zbyvaStr = StringUtils::format('minuty', $zbyva);

$colZakazka = 6 - ($this ->editovatHodiny ? 1 : 0) - ($this ->editovatCasy ? 1 : 0);
$colCinnost = 5 - ($this ->editovatCasy ? 1 : 0);

?>

<div class="rozdeleniVyrobyOsoby" data-idpp="<?= $this ->pp ->idPP ?>" data-den="<?= DateUtils::dateToUrlString($this ->den) ?>"
     data-xml-beforepost="<?= RonPortalXMLEvents::VYROBA_BEFORE_POST ?> data-xml-afterpost="<?= RonPortalXMLEvents::VYROBA_AFTER_POST ?>">
    <input type="hidden" name="ulozrozdelenivyroby" value="1"/>

    <div class="row form-section">
        <div class="col col-<?= $colZakazka ?>"><?= \Ron\ronText('Vyroba_zakazka') ?></div>
        <div class="col col-<?= $colCinnost ?>"><?= \Ron\ronText('Vyroba_cinnost') ?></div>

        <?php if ($this ->editovatCasy) { ?>
            <div class="col col-1"><?= \Ron\ronText('Vyroba_casod') ?></div>
            <div class="col col-1"><?= \Ron\ronText('Vyroba_casdo') ?></div>
        <?php } ?>

        <?php if ($this ->editovatHodiny) { ?>
        <div class="col col-1"><?= \Ron\ronText('Vyroba_hodiny') ?></div>
        <?php } ?>
    </div>

    <?php
    foreach ($this ->zaznamy as $index => $zaznam) { ?>
        <div id="vyroba_row<?= $index ?>" class="radekDenniVyrobyOsoby" data-rowindex="<?= $index ?>">
            <input type="hidden" name="vyroba<?= $index ?>_serial" value="<?= $zaznam ->serialVyroba ?>" />
            <div class="row">
                <div class="col col-<?= $colZakazka ?>"><?php $this ->renderComboZakazka("vyroba{$index}_vyrobniZakazka", $zaznam ->zakazka); ?></div>
                <div class="col col-<?= $colCinnost ?>"><?php $this ->renderComboCinnost("vyroba{$index}_cinnost", $this ->jenPrirazeneCinnosti ? $zaznam ->cinnostVyrobniZakazky : $zaznam ->cinnost, $zaznam ->zakazka) ?></div>

                <?php if ($this ->editovatCasy) { ?>
                    <div class="col col-1">
                        <input name="vyroba<?= $index ?>_casOd" <?= $this ->readOnly ? 'readonly="readonly"' : '' ?>
                               class="form-input align-right inputTime vyroba_casOd <?= MessageManager::getClass("vyroba{$index}_casOd")?>"
                               value="<?= StringUtils::htmlTextConvert($zaznam ->casOdStr) ?>"/>
                    </div>
                    <div class="col col-1">
                        <input name="vyroba<?= $index ?>_casDo" <?= $this ->readOnly ? 'readonly="readonly"' : '' ?>
                               class="form-input align-right inputTime vyroba_casDo <?= MessageManager::getClass("vyroba{$index}_casDo")?>"
                               value="<?= StringUtils::htmlTextConvert($zaznam ->casDoStr) ?>"/>
                    </div>
                <?php } ?>

                <?php if ($this ->editovatHodiny) { ?>
                <div class="col col-1">
                    <input name="vyroba<?= $index ?>_hodiny" <?= $this ->readOnly ? 'readonly="readonly"' : '' ?>
                           class="form-input align-right inputTime vyroba_hodiny <?= MessageManager::getClass("vyroba{$index}_hodiny")?>"
                           value="<?= StringUtils::htmlTextConvert($zaznam ->hodinyStr) ?>"/>
                </div>
                <?php } ?>

                <div class="col col-1">
                    h
                    <?php if (!$this ->readOnly) { ?>
                    <i class="inline-glyph glyph-button far fa-comment-alt toggleClass " data-selector="#vyroba_row<?= $index ?>" data-add-class="zobrazitPoznamky" title="<?= \Ron\ronText('Zobrazit_poznamky') ?>">
                    </i>

                        <?php if ($zaznam ->serialVyroba) { ?>
                        <i class="inline-glyph glyph-button fa glyph-delete vyroba_delete" title="<?= \Ron\ronText('Smazat_cely_radek') ?>" data-ron-confirm-text="<?= \Ron\ronText('Opravdu_smazat_cely_radek') ?>" data-serial="<?= $zaznam ->serialVyroba ?>"></i>
                        <?php } ?>
                    <?php } ?>
                </div>
            </div>
            <!-- poznamky -->
            <div class="row popis <?= $zaznam ->popis ? '' : 'prazdnyPopis' ?>">
                <div class="col col-11">
                    <?php if ($this ->readOnly) { ?>
                        <div class="poznamka"><?= StringUtils::htmlTextConvert($zaznam ->popis) ?></div>
                    <?php } else { ?>
                        <input maxlength="80" name="vyroba<?= $index ?>_popis" class="form-input" value="<?= StringUtils::htmlTextConvert($zaznam ->popis) ?>"/>
                    <?php } ?>
                </div>
                <div class="col col-1 overflow-hidden"><?= \Ron\ronText('Vyroba_popis') ?></div>
            </div>
            <div class="row rozsirujiciPopis <?= $zaznam ->rozsirujiciPopis ? '' : 'prazdnyPopis' ?>">
                <div class="col col-11">
                    <?php if ($this ->readOnly) { ?>
                        <div class="poznamka"><?= StringUtils::htmlTextConvert($zaznam ->rozsirujiciPopis) ?></div>
                    <?php } else { ?>
                        <textarea name="vyroba<?= $index ?>_rozsirujiciPopis" class="form-input"><?= StringUtils::htmlTextConvert($zaznam ->rozsirujiciPopis) ?></textarea>
                    <?php } ?>
                </div>
                <div class="col col-1 overflow-hidden"><?= \Ron\ronText('Vyroba_rozsirujici_popis') ?></div>
            </div>
            <div class="form-gap popis <?= $zaznam ->popis || $zaznam ->rozsirujiciPopis ? '' : 'prazdnyPopis' ?>"></div>
        </div>
    <?php } ?>

    <!-- soucet -->
    <?php if (isset($this ->odpracovano)) { // zobrazi soucet/kolik zbyva ?>
        <div class="row">
            <div class="col col-6"><?= \Ron\ronText('Celkem_rozdelit') ?>: <strong><?= $odpracovanoStr ?></strong></div>
            <div class="col col-5 align-right">
                <?= \Ron\ronText('Zbyva_rozdelit') ?>:
                <strong><span class="input_margins<?= $zbyva < 0 ? ' minus' : '' ?>" data-ron-sum="<?= $odpracovanoStr ?>" id="Vyroba_Zbyva"><?= $zbyvaStr ?></span></strong>
            </div>
            <div class="col col-1">h</div>
        </div>
    <?php } else { ?>
        <div class="row">
            <div class="col col-11 align-right"><?= \Ron\ronText('Soucet') ?>: <strong><span id='Vyroba_Soucet'><?= $soucetStr ?></span></strong></div>
            <div class="col col-1">h</div>
        </div>
    <?php } ?>

    <input type="hidden" name="vyroba_COUNT" id="vyroba_COUNT" value="<?= count($this ->zaznamy) ?>" />
    <input type="hidden" name="vyroba_delete_row" id="vyroba_delete_row" value="" />

    <?php if (!$this->readOnly) { // umozni pridat novy radek pomoci tlacitka ?>
        <div class="row">
            <div class="col col-3">
                <input class="button" type="submit" name="novyradekvyroby" value="<?= \Ron\ronText('Novy_radek') ?>" />
            </div>

            <div class="col col-9 align-right">
                <input class="button" type="submit" id="vyroba_doplnitpodlepredchozi" name="doplnitpodlepredchoziho"
                       value="<?= \Ron\ronText('Doplnit_vyrobu_podle_predchoziho') ?>"
                       title="<?= \Ron\ronText('Doplnit_vyrobu_podle_predchoziho_dne_info') ?>" />
                <?php if (RonPortalSettings::getValue('vyroba_agenthost')) { ?>
                <input class="button confirmQuestion" type="button" id="vyroba_podlepuvodni" name="podlepuvodnivyroby"
                       value="<?= \Ron\ronText('Vyroba_podle_puvodni') ?>"
                       title="<?= \Ron\ronText('Vyroba_podle_puvodni_info') ?>"
                       data-ron-href="?menuid=editacedne&action=podlepuvodnivyroby&idpp=<?= $this ->pp ->idPP ?>&datum=<?= $this ->den ?>"
                       data-ron-confirm-text="<?= \Ron\ronText('Opravdu_podle_puvodni_vyroby') ?>"
                       data-ron-working-info="<?= \Ron\ronText('Probiha_zpracovani_dat') ?>"
                    />
                <?php } ?>
            </div>
        </div>
    <?php } ?>

    <!-- POZNAMKA ! -->
</div>
